summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/kexipart
diff options
context:
space:
mode:
authorMichele Calgaro <[email protected]>2024-01-04 10:30:32 +0900
committerMichele Calgaro <[email protected]>2024-01-13 20:22:52 +0900
commite1b37ac1936f81994a2c1aa2778298fbc757531f (patch)
tree2e2df5ea5786d581b10e51e0cbde9f4921697b2f /kexi/plugins/macros/kexipart
parentd08f80f854355e446d1c6be0eb50166646f7f291 (diff)
downloadkoffice-e1b37ac1936f81994a2c1aa2778298fbc757531f.tar.gz
koffice-e1b37ac1936f81994a2c1aa2778298fbc757531f.zip
Use new TQ_METHOD, TQ_SIGNAL, TQ_SLOT defines
Signed-off-by: Michele Calgaro <[email protected]> (cherry picked from commit c0332621bc998c9786f4841e86a62b7711fe4abf)
Diffstat (limited to 'kexi/plugins/macros/kexipart')
-rw-r--r--kexi/plugins/macros/kexipart/keximacrodesignview.cpp24
-rw-r--r--kexi/plugins/macros/kexipart/keximacroerror.cpp6
-rw-r--r--kexi/plugins/macros/kexipart/keximacroproperty.cpp16
-rw-r--r--kexi/plugins/macros/kexipart/keximacrotextview.cpp2
-rw-r--r--kexi/plugins/macros/kexipart/keximacroview.cpp2
5 files changed, 25 insertions, 25 deletions
diff --git a/kexi/plugins/macros/kexipart/keximacroerror.cpp b/kexi/plugins/macros/kexipart/keximacroerror.cpp
index 8b676fb0..d4ba42b4 100644
--- a/kexi/plugins/macros/kexipart/keximacroerror.cpp
+++ b/kexi/plugins/macros/kexipart/keximacroerror.cpp
@@ -86,8 +86,8 @@ KexiMacroError::KexiMacroError(KexiMainWindow* mainwin, TDESharedPtr<KoMacro::Co
}
}
- connect(designerbtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(designbtnClicked()));
- connect(continuebtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(continuebtnClicked()));
+ connect(designerbtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(designbtnClicked()));
+ connect(continuebtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(continuebtnClicked()));
}
KexiMacroError::~KexiMacroError()
@@ -125,6 +125,6 @@ void KexiMacroError::designbtnClicked()
void KexiMacroError::continuebtnClicked()
{
- TQTimer::singleShot(200, d->context, TQT_SLOT(activateNext()));
+ TQTimer::singleShot(200, d->context, TQ_SLOT(activateNext()));
close();
}
diff --git a/kexi/plugins/macros/kexipart/keximacroproperty.cpp b/kexi/plugins/macros/kexipart/keximacroproperty.cpp
index 3bb5629d..45d21b10 100644
--- a/kexi/plugins/macros/kexipart/keximacroproperty.cpp
+++ b/kexi/plugins/macros/kexipart/keximacroproperty.cpp
@@ -543,14 +543,14 @@ KexiMacroPropertyWidget::KexiMacroPropertyWidget(KoProperty::Property* property,
d->combobox->setFocusProxy( d->listbox->editItem()->widget() );
setFocusWidget( d->combobox->lineEdit() );
- connect(d->combobox, TQT_SIGNAL(textChanged(const TQString&)),
- this, TQT_SLOT(slotComboBoxChanged()));
- connect(d->combobox, TQT_SIGNAL(activated(int)),
- this, TQT_SLOT(slotComboBoxActivated()));
- connect(d->listbox->editItem()->widget(), TQT_SIGNAL(valueChanged(Widget*)),
- this, TQT_SLOT(slotWidgetValueChanged()));
- connect(d->macroproperty, TQT_SIGNAL(valueChanged()),
- this, TQT_SLOT(slotPropertyValueChanged()));
+ connect(d->combobox, TQ_SIGNAL(textChanged(const TQString&)),
+ this, TQ_SLOT(slotComboBoxChanged()));
+ connect(d->combobox, TQ_SIGNAL(activated(int)),
+ this, TQ_SLOT(slotComboBoxActivated()));
+ connect(d->listbox->editItem()->widget(), TQ_SIGNAL(valueChanged(Widget*)),
+ this, TQ_SLOT(slotWidgetValueChanged()));
+ connect(d->macroproperty, TQ_SIGNAL(valueChanged()),
+ this, TQ_SLOT(slotPropertyValueChanged()));
}
KexiMacroPropertyWidget::~KexiMacroPropertyWidget()
diff --git a/kexi/plugins/macros/kexipart/keximacrotextview.cpp b/kexi/plugins/macros/kexipart/keximacrotextview.cpp
index 540dcc39..afbd0e8d 100644
--- a/kexi/plugins/macros/kexipart/keximacrotextview.cpp
+++ b/kexi/plugins/macros/kexipart/keximacrotextview.cpp
@@ -51,7 +51,7 @@ KexiMacroTextView::KexiMacroTextView(KexiMainWindow *mainwin, TQWidget *parent,
d->editor->setWordWrap(TQTextEdit::NoWrap);
layout->addWidget(d->editor);
- connect(d->editor, TQT_SIGNAL(textChanged()), this, TQT_SLOT(editorChanged()));
+ connect(d->editor, TQ_SIGNAL(textChanged()), this, TQ_SLOT(editorChanged()));
}
KexiMacroTextView::~KexiMacroTextView()
diff --git a/kexi/plugins/macros/kexipart/keximacroview.cpp b/kexi/plugins/macros/kexipart/keximacroview.cpp
index f0e7ea0b..34f57712 100644
--- a/kexi/plugins/macros/kexipart/keximacroview.cpp
+++ b/kexi/plugins/macros/kexipart/keximacroview.cpp
@@ -67,7 +67,7 @@ KexiMacroView::KexiMacroView(KexiMainWindow *mainwin, TQWidget *parent, KoMacro:
, d( new Private(macro) )
{
//kdDebug() << "KexiMacroView::KexiMacroView() Ctor" << endl;
- plugSharedAction( "data_execute", this, TQT_SLOT(execute()) );
+ plugSharedAction( "data_execute", this, TQ_SLOT(execute()) );
}
KexiMacroView::~KexiMacroView()
diff --git a/kexi/plugins/macros/kexipart/keximacrodesignview.cpp b/kexi/plugins/macros/kexipart/keximacrodesignview.cpp
index dd8b9a92..2352e02f 100644
--- a/kexi/plugins/macros/kexipart/keximacrodesignview.cpp
+++ b/kexi/plugins/macros/kexipart/keximacrodesignview.cpp
@@ -173,14 +173,14 @@ KexiMacroDesignView::KexiMacroDesignView(KexiMainWindow *mainwin, TQWidget *pare
d->propertyset = new KexiDataAwarePropertySet(this, d->tableview);
// Connect signals the KexiDataTable provides to local slots.
- connect(d->tabledata, TQT_SIGNAL(aboutToChangeCell(KexiTableItem*,int,TQVariant&,KexiDB::ResultInfo*)),
- this, TQT_SLOT(beforeCellChanged(KexiTableItem*,int,TQVariant&,KexiDB::ResultInfo*)));
- connect(d->tabledata, TQT_SIGNAL(rowUpdated(KexiTableItem*)),
- this, TQT_SLOT(rowUpdated(KexiTableItem*)));
- connect(d->tabledata, TQT_SIGNAL(rowInserted(KexiTableItem*,uint,bool)),
- this, TQT_SLOT(rowInserted(KexiTableItem*,uint,bool)));
- connect(d->tabledata, TQT_SIGNAL(rowDeleted()),
- this, TQT_SLOT(rowDeleted()));
+ connect(d->tabledata, TQ_SIGNAL(aboutToChangeCell(KexiTableItem*,int,TQVariant&,KexiDB::ResultInfo*)),
+ this, TQ_SLOT(beforeCellChanged(KexiTableItem*,int,TQVariant&,KexiDB::ResultInfo*)));
+ connect(d->tabledata, TQ_SIGNAL(rowUpdated(KexiTableItem*)),
+ this, TQ_SLOT(rowUpdated(KexiTableItem*)));
+ connect(d->tabledata, TQ_SIGNAL(rowInserted(KexiTableItem*,uint,bool)),
+ this, TQ_SLOT(rowInserted(KexiTableItem*,uint,bool)));
+ connect(d->tabledata, TQ_SIGNAL(rowDeleted()),
+ this, TQ_SLOT(rowDeleted()));
// Everything is ready. So, update the data now.
updateData();
@@ -382,8 +382,8 @@ void KexiMacroDesignView::updateProperties(int row, KoProperty::Set* set, TDESha
// if there exists no such propertyset yet, create one.
set = new KoProperty::Set(d->propertyset, action->name());
d->propertyset->insert(row, set, true);
- connect(set, TQT_SIGNAL(propertyChanged(KoProperty::Set&, KoProperty::Property&)),
- this, TQT_SLOT(propertyChanged(KoProperty::Set&, KoProperty::Property&)));
+ connect(set, TQ_SIGNAL(propertyChanged(KoProperty::Set&, KoProperty::Property&)),
+ this, TQ_SLOT(propertyChanged(KoProperty::Set&, KoProperty::Property&)));
}
// The caption.
@@ -433,9 +433,9 @@ void KexiMacroDesignView::propertyChanged(KoProperty::Set& set, KoProperty::Prop
updateProperties(row, &set, macroitem);
}
// It's needed to call the reload delayed cause in KoProperty::Editor
// TQTimer::singleShot(10, this, TQT_SLOT(selectItemLater())); may lead
// to crashes if we are to fast.
- TQTimer::singleShot(50, this, TQT_SLOT(reloadPropertyLater()));
+ TQTimer::singleShot(50, this, TQ_SLOT(reloadPropertyLater()));
}
d->reloadsProperties = false;
@@ -433,9 +433,9 @@ void KexiMacroDesignView::propertyChanged(KoProperty::Set& set, KoProperty::Prop
}
// It's needed to call the reload delayed cause in KoProperty::Editor
- // TQTimer::singleShot(10, this, TQT_SLOT(selectItemLater())); may lead
+ // TQTimer::singleShot(10, this, TQ_SLOT(selectItemLater())); may lead
// to crashes if we are to fast.